@@ -1,9 +1,12 @@
 __title__ = 'datclass'
 __author__ = 'foyoux'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
+__all__ = ['DatClass', 'main']
 
 import argparse
 
+from datclass.datclass import DatClass
+
 
 def main():
     epilog = f'%(prog)s({__version__}) by foyoux(https://github.com/foyoux/datclass)'
